.. _section_release_notes:

Release Notes
=============

This is the list of changes to `cotainr` between each release. For full changelog details,
see the `commit logs <https://github.com/DeiC-HPC/cotainr/commits/>`_.

..
    The release_list.rst may be generated using create_release_notes_list.py

.. include:: release_list.rst
